@@ -1,6 +1,6 @@
 # **********************************************************************
 #
-# Copyright (c) 2003-2005 ZeroC, Inc. All rights reserved.
+# Copyright (c) 2003-2007 ZeroC, Inc. All rights reserved.
 #
 # This copy of Ice is licensed to you under the terms described in the
 # ICE_LICENSE file included in this distribution.
@@ -8,21 +8,9 @@
 # **********************************************************************
 
 #
-# Checks for ICE_HOME environment variable.  If it isn't present it will
-# attempt to find an Ice installation in /usr.
+# If you are compiling with MONO you must define this symbol.
 #
-
-ifeq ($(ICE_HOME),)
-    ICE_DIR = /usr
-    ifneq ($(shell test -f $(ICE_DIR)/bin/icestormadmin && echo 0),0)
-$(error Ice distribution not found, please set ICE_HOME!)
-    endif
-else
-    ICE_DIR = $(ICE_HOME)
-    ifneq ($(shell test -d $(ICE_DIR)/slice && echo 0),0)
-$(error Ice distribution not found, please set ICE_HOME!)
-    endif
-endif
+MONO = yes
 
 #
 # Select an installation base directory. The directory will be created
@@ -48,12 +36,54 @@ prefix			= /opt/IceCS-$(VERSION)
 
 DEBUG			= yes
 
+#OPTIMIZE		= yes
+
 # ----------------------------------------------------------------------
 # Don't change anything below this line!
 # ----------------------------------------------------------------------
 
+
+ifeq ($(MONO), yes)
+	DSEP = /
+else
+	DSEP = \\
+endif
+
 SHELL			= /bin/sh
-VERSION			= 3.1.1
+VERSION			= 3.2.1
+
+#
+# Checks for ICE_HOME environment variable.  If it isn't present,
+# attempt to find an Ice installation in /usr or the default install
+# location.
+#
+ifeq ($(ICE_HOME),)
+    ICE_DIR = /usr
+    ifneq ($(shell test -f $(ICE_DIR)/bin/slice2cs && echo 0),0)
+	NEXTDIR = /opt/Ice-$(VERSION)
+	ifneq ($(shell test -f $(NEXTDIR)/bin/slice2cs && echo 0),0)
+$(error Unable to locate Ice distribution, please set ICE_HOME!)
+	else
+	    ICE_DIR = $(NEXTDIR)
+	endif
+    else
+	NEXTDIR = /opt/IceCS-$(VERSION)
+	ifeq ($(shell test -f $(NEXTDIR)/bin/slice2cs && echo 0),0)
+$(warning Ice distribution found in /usr and $(NEXTDIR)! Installation in "/usr" will be used by default. Use ICE_HOME to specify alternate Ice installation.)
+	endif
+    endif
+else
+    ICE_DIR = $(ICE_HOME)
+    ifneq ($(shell test -f $(ICE_DIR)/bin/slice2cs && echo 0),0)
+$(error Ice distribution not found in $(ICE_DIR), please verify ICE_HOME location!)
+    endif
+endif
+
+ifeq ($(LP64),yes)
+    export LD_LIBRARY_PATH := $(ICE_DIR)/lib64:$(LD_LIBRARY_PATH)
+else
+    export LD_LIBRARY_PATH := $(ICE_DIR)/lib:$(LD_LIBRARY_PATH)
+endif
 
 bindir			= $(top_srcdir)/bin
 libdir			= $(top_srcdir)/lib
@@ -64,7 +94,7 @@ libdir			= $(top_srcdir)/lib
 #
 ifneq ($(shell test -d $(top_srcdir)/slice && echo 0),0)
     ifeq ($(ICE_DIR),/usr)
-	slicedir = $(ICE_DIR)/share/slice
+	slicedir = $(ICE_DIR)/share/Ice-$(VERSION)/slice
     else
 	slicedir = $(ICE_DIR)/slice
     endif
@@ -93,15 +123,23 @@ INSTALL_DATA		= ${INSTALL}
 
 GACUTIL			= gacutil
 
-MCS			= mcs
+ifeq ($(MONO),yes)
+MCS			= gmcs
+else
+MCS			= csc -nologo
+endif
 
 LIBS			= $(bindir)/icecs.dll $(bindir)/glaciercs.dll
 
-MCSFLAGS = -warnaserror
+MCSFLAGS = -warnaserror -d:MAKEFILE_BUILD
 ifeq ($(DEBUG),yes)
     MCSFLAGS := $(MCSFLAGS) -debug -define:DEBUG
 endif
 
+ifeq ($(OPTIMIZE),yes)
+    MCSFLAGS := $(MCSFLAGS) -optimize+
+endif
+
 ifeq ($(installdata),)
     installdata		= $(INSTALL_DATA) $(1) $(2); \
 			  chmod a+r $(2)/$(notdir $(1))
@@ -130,7 +168,8 @@ SGEN_SRCS = $(subst .ice,.cs,$(addprefix $(GDIR)/,$(notdir $(SLICE_S_SRCS))))
 GEN_AMD_SRCS = $(subst .ice,.cs,$(addprefix $(GDIR)/,$(notdir $(SLICE_AMD_SRCS))))
 SAMD_GEN_SRCS = $(subst .ice,.cs,$(addprefix $(GDIR)/,$(notdir $(SLICE_SAMD_SRCS))))
 
-EVERYTHING		= all depend clean install
+
+EVERYTHING		= all depend clean install config
 
 .SUFFIXES:
 .SUFFIXES:		.cs .ice
@@ -144,7 +183,6 @@ $(GDIR)/%.cs: $(SDIR)/%.ice
 all:: $(TARGETS)
 
 depend:: $(SLICE_SRCS) $(SLICE_C_SRCS) $(SLICE_S_SRCS) $(SLICE_AMD_SRCS) $(SLICE_SAMD_SRCS)
-	echo "slicedir: $(slicedir)"
 	-rm -f .depend
 	if test -n "$(SLICE_SRCS)" ; then \
 	    $(SLICE2CS) --depend $(SLICE2CSFLAGS) $(SLICE_SRCS) | \
@@ -168,7 +206,10 @@ depend:: $(SLICE_SRCS) $(SLICE_C_SRCS) $(SLICE_S_SRCS) $(SLICE_AMD_SRCS) $(SLICE
 	fi
 
 clean::
-	-rm -f $(TARGETS) $(patsubst %,%.mdb,$(TARGETS)) *.bak *.dll *.pdb
+	-rm -f $(TARGETS) $(patsubst %,%.mdb,$(TARGETS)) *.bak *.dll *.pdb *.mdb
+
+config::
+	$(top_srcdir)/config/makeconfig.py $(top_srcdir) $(TARGETS)
 
 ifneq ($(SLICE_SRCS),)
 clean::
