@@ -1,7 +1,7 @@
 #!/usr/bin/env python
 # **********************************************************************
 #
-# Copyright (c) 2003-2006 ZeroC, Inc. All rights reserved.
+# Copyright (c) 2003-2007 ZeroC, Inc. All rights reserved.
 #
 # This copy of Ice is licensed to you under the terms described in the
 # ICE_LICENSE file included in this distribution.
@@ -28,8 +28,8 @@ compress = 0
 # thread per connection mode.
 #
 
-#threadPerConnection = 0
-threadPerConnection = 1
+threadPerConnection = 0
+#threadPerConnection = 1
 
 #
 # To print the commands that are being run.
@@ -44,7 +44,6 @@ import sys, os, re, errno, getopt
 from threading import Thread
 
 def isCygwin():
-
     # The substring on sys.platform is required because some cygwin
     # versions return variations like "cygwin_nt-4.01".
     if sys.platform[:6] == "cygwin":
@@ -53,7 +52,6 @@ def isCygwin():
         return 0
 
 def isWin32():
-
     if sys.platform == "win32" or isCygwin():
         return 1
     else:
@@ -61,12 +59,12 @@ def isWin32():
 
 def usage():
     print "usage: " + sys.argv[0] + " -m|--mono --debug --protocol protocol --compress --host host "\
-	"--threadPerConnection"
+        "--threadPerConnection"
     sys.exit(2)
 
 try:
     opts, args = getopt.getopt(sys.argv[1:], "m",\
-	 ["mono", "debug", "protocol=", "compress", "host=", "threadPerConnection"])
+         ["mono", "debug", "protocol=", "compress", "host=", "threadPerConnection"])
 except getopt.GetoptError:
     usage()
 
@@ -74,17 +72,19 @@ mono = 0
 
 for o, a in opts:
     if o in ( "-m", "--mono" ):
-	mono = 1
+        mono = 1
     if o == "--debug":
-	debug = 1
+        debug = 1
     if o == "--protocol":
-	protocol = a
+        if a not in ( "tcp", "ssl"):
+            usage()
+        protocol = a
     if o == "--compress":
-	compress = 1
+        compress = 1
     if o == "--threadPerConnection":
-	threadPerConnection = 1
+        threadPerConnection = 1
     if o == "--host":
-	host = a
+        host = a
 
 if protocol == "ssl":
     threadPerConnection = 1
@@ -108,16 +108,16 @@ host = "127.0.0.1"
 def closePipe(pipe):
 
     try:
-	status = pipe.close()
+        status = pipe.close()
     except IOError, ex:
-	# TODO: There's a waitpid problem on CentOS, so we have to ignore ECHILD.
-	if ex.errno == errno.ECHILD:
-	    status = 0
-	# This happens with the C# fault tolerance test. Ignore this error.
-	elif ex.errno == 0:
-	    status = 0
-	else:
-	    raise
+        # TODO: There's a waitpid problem on CentOS, so we have to ignore ECHILD.
+        if ex.errno == errno.ECHILD:
+            status = 0
+        # This happens with the C# fault tolerance test. Ignore this error.
+        elif ex.errno == 0:
+            status = 0
+        else:
+            raise
 
     return status
      
@@ -132,17 +132,17 @@ class ReaderThread(Thread):
             while 1:
                 line = self.pipe.readline()
                 if not line: break
-		# Suppress "adapter ready" messages. Under windows the eol isn't \n.
-		if not line.endswith(" ready\n") and not line.endswith(" ready\r\n"):
-		    print line,
+                # Suppress "adapter ready" messages. Under windows the eol isn't \n.
+                if not line.endswith(" ready\n") and not line.endswith(" ready\r\n"):
+                    print line,
         except IOError:
-	    print "IOError"
+            print "IOError"
             pass
 
-	self.status = closePipe(self.pipe)
+        self.status = closePipe(self.pipe)
 
     def getStatus(self):
-	return self.status
+        return self.status
 
 serverPids = []
 serverThreads = []
@@ -152,17 +152,17 @@ def joinServers():
     global serverThreads
     global allServerThreads
     for t in serverThreads:
-	t.join()
-	allServerThreads.append(t)
+        t.join()
+        allServerThreads.append(t)
     serverThreads = []
 
 def serverStatus():
     global allServerThreads
     joinServers()
     for t in allServerThreads:
-    	status = t.getStatus()
-    	if status:
-    	    return status
+        status = t.getStatus()
+        if status:
+            return status
     return 0
 
 def killServers():
@@ -200,32 +200,32 @@ def getServerPid(pipe):
     global serverThreads
 
     while 1:
-	output = pipe.readline().strip()
-	if not output:
-	    print "failed!"
-	    killServers()
-	    sys.exit(1)
-    	if output.startswith("warning: "):
-    	    continue
-	break
+        output = pipe.readline().strip()
+        if not output:
+            print "failed!"
+            killServers()
+            sys.exit(1)
+        if output.startswith("warning: "):
+            continue
+        break
 
     try:
-	serverPids.append(int(output))
+        serverPids.append(int(output))
     except ValueError:
-	print "Output is not a PID: " + output
-	raise
+        print "Output is not a PID: " + output
+        raise
 
 def ignorePid(pipe):
 
     while 1:
-	output = pipe.readline().strip()
-	if not output:
-	    print "failed!"
-	    killServers()
-	    sys.exit(1)
-    	if output.startswith("warning: "):
-    	    continue
-	break
+        output = pipe.readline().strip()
+        if not output:
+            print "failed!"
+            killServers()
+            sys.exit(1)
+        if output.startswith("warning: "):
+            continue
+        break
 
 def getAdapterReady(pipe, createThread = True, count = 1):
     global serverThreads
@@ -241,9 +241,9 @@ def getAdapterReady(pipe, createThread = True, count = 1):
 
     # Start a thread for this server.
     if createThread:
-	serverThread = ReaderThread(pipe)
-	serverThread.start()
-	serverThreads.append(serverThread)
+        serverThread = ReaderThread(pipe)
+        serverThread.start()
+        serverThreads.append(serverThread)
 
 def waitServiceReady(pipe, token, createThread = True):
     global serverThreads
@@ -258,9 +258,9 @@ def waitServiceReady(pipe, token, createThread = True):
 
     # Start a thread for this server.
     if createThread:
-	serverThread = ReaderThread(pipe)
-	serverThread.start()
-	serverThreads.append(serverThread)
+        serverThread = ReaderThread(pipe)
+        serverThread.start()
+        serverThreads.append(serverThread)
 
 def printOutputFromPipe(pipe):
 
@@ -279,29 +279,38 @@ else:
 
 if isWin32():
     if isCygwin():
-	os.environ["PATH"] = os.path.join(toplevel, "bin") + ":" + os.getenv("PATH", "")
+        os.environ["PATH"] = os.path.join(toplevel, "bin") + ":" + os.getenv("PATH", "")
     else:
-	os.environ["PATH"] = os.path.join(toplevel, "bin") + ";" + os.getenv("PATH", "")
+        os.environ["PATH"] = os.path.join(toplevel, "bin") + ";" + os.getenv("PATH", "")
+
+if mono:
+    sep = ""
+    if isWin32():
+        sep = ";"
+    else:
+        sep = ":"
+    os.environ["MONO_PATH"] = os.path.join(toplevel, "bin") + sep + os.getenv("MONO_PATH", "")
+
 
 if protocol == "ssl":
-    plugin		 = " --Ice.Plugin.IceSSL=" + os.path.join(toplevel, "bin", "icesslcs.dll") + \
-			   ":IceSSL.PluginFactory"
+    plugin               = " --Ice.Plugin.IceSSL=" + os.path.join(toplevel, "bin", "icesslcs.dll") + \
+                           ":IceSSL.PluginFactory"
     clientProtocol       = plugin + " --Ice.Default.Protocol=ssl" + \
                            " --IceSSL.CertFile=" + os.path.join(toplevel, "certs", "c_rsa1024.pfx") + \
                            " --IceSSL.Password=password" + \
                            " --IceSSL.CheckCertName=0"
     serverProtocol       = plugin + " --Ice.Default.Protocol=ssl" + \
-                           " --IceSSL.ImportCert.LocalMachine.AuthRoot=" + \
-				os.path.join(toplevel, "certs", "cacert.pem") + \
+                           " --IceSSL.ImportCert.CurrentUser.Root=" + \
+                                os.path.join(toplevel, "certs", "cacert.pem") + \
                            " --IceSSL.CertFile=" + os.path.join(toplevel, "certs", "s_rsa1024.pfx") + \
                            " --IceSSL.Password=password"
     clientServerProtocol = plugin + " --Ice.Default.Protocol=ssl" + \
-                           " --IceSSL.ImportCert.LocalMachine.AuthRoot=" + \
-				os.path.join(toplevel, "certs", "cacert.pem") + \
+                           " --IceSSL.ImportCert.CurrentUser.Root=" + \
+                                os.path.join(toplevel, "certs", "cacert.pem") + \
                            " --IceSSL.CertFile=" + os.path.join(toplevel, "certs", "c_rsa1024.pfx") + \
                            " --IceSSL.Password=password" + \
                            " --IceSSL.CheckCertName=0"
-    cppPlugin		    = " --Ice.Plugin.IceSSL=IceSSL:createIceSSL"
+    cppPlugin               = " --Ice.Plugin.IceSSL=IceSSL:createIceSSL"
     cppClientProtocol       = cppPlugin + " --Ice.Default.Protocol=ssl" + \
                               " --IceSSL.DefaultDir=" + os.path.join(toplevel, "certs") + \
                               " --IceSSL.CertAuthFile=cacert.pem" + \
@@ -346,12 +355,10 @@ commonServerOptions = " --Ice.PrintProcessId --Ice.PrintAdapterReady --Ice.NullH
                       " --Ice.ThreadPool.Server.Size=1 --Ice.ThreadPool.Server.SizeMax=3" + \
                       " --Ice.ThreadPool.Server.SizeWarn=0"
 
-cppCommonClientOptions = " --Ice.Warn.Connections"
+cppCommonClientOptions = " --Ice.NullHandleAbort --Ice.Warn.Connections"
 
-cppCommonServerOptions = " --Ice.PrintAdapterReady" + \
-                         " --Ice.Warn.Connections --Ice.ServerIdleTime=30" + \
-                         " --Ice.ThreadPool.Server.Size=1 --Ice.ThreadPool.Server.SizeMax=3" + \
-                         " --Ice.ThreadPool.Server.SizeWarn=0"
+cppCommonServerOptions = " --Ice.PrintProcessId --Ice.PrintAdapterReady --Ice.NullHandleAbort" + \
+                         " --Ice.Warn.Connections --Ice.ServerIdleTime=30"
 
 cppClientOptions = cppClientProtocol + defaultHost + cppCommonClientOptions
 cppServerOptions = cppServerProtocol + defaultHost + cppCommonServerOptions
@@ -365,7 +372,7 @@ collocatedOptions = clientServerProtocol + defaultHost
 def createMsg(name):
     msg = "starting "
     if mono:
-	msg += "mono "
+        msg += "mono "
     msg += name
     if mono:
         msg += ".exe"
@@ -390,7 +397,7 @@ def clientServerTestWithOptionsAndNames(name, additionalServerOptions, additiona
     print createMsg(serverName),
     serverCmd = createCmd(server) + serverOptions + " " + additionalServerOptions
     if debug:
-	print "(" + serverCmd + ")",
+        print "(" + serverCmd + ")",
     serverPipe = os.popen(serverCmd + " 2>&1")
     getServerPid(serverPipe)
     getAdapterReady(serverPipe)
@@ -399,7 +406,7 @@ def clientServerTestWithOptionsAndNames(name, additionalServerOptions, additiona
     print createMsg(clientName),
     clientCmd = createCmd(client) + clientOptions + " " + additionalClientOptions
     if debug:
-	print "(" + clientCmd + ")",
+        print "(" + clientCmd + ")",
     clientPipe = os.popen(clientCmd + " 2>&1")
     print "ok"
 
@@ -407,7 +414,7 @@ def clientServerTestWithOptionsAndNames(name, additionalServerOptions, additiona
 
     clientStatus = closePipe(clientPipe)
     if clientStatus:
-	killServers()
+        killServers()
 
     if clientStatus or serverStatus():
         sys.exit(1)
@@ -430,7 +437,7 @@ def mixedClientServerTestWithOptions(name, additionalServerOptions, additionalCl
     print createMsg("server"),
     serverCmd = createCmd(server) + clientServerOptions + " " + additionalServerOptions
     if debug:
-	print "(" + serverCmd + ")",
+        print "(" + serverCmd + ")",
     serverPipe = os.popen(serverCmd + " 2>&1")
     getServerPid(serverPipe)
     getAdapterReady(serverPipe)
@@ -439,7 +446,7 @@ def mixedClientServerTestWithOptions(name, additionalServerOptions, additionalCl
     print createMsg("client"),
     clientCmd = createCmd(client) + clientServerOptions + " " + additionalClientOptions
     if debug:
-	print "(" + clientCmd + ")",
+        print "(" + clientCmd + ")",
     clientPipe = os.popen(clientCmd + " 2>&1")
     ignorePid(clientPipe)
     getAdapterReady(clientPipe, False)
@@ -449,7 +456,7 @@ def mixedClientServerTestWithOptions(name, additionalServerOptions, additionalCl
 
     clientStatus = closePipe(clientPipe)
     if clientStatus:
-	killServers()
+        killServers()
 
     if clientStatus or serverStatus():
         sys.exit(1)
@@ -466,7 +473,7 @@ def collocatedTestWithOptions(name, additionalOptions):
     print createMsg("collocated"),
     command = createCmd(collocated) + collocatedOptions + " " + additionalOptions
     if debug:
-	print "(" + command + ")",
+        print "(" + command + ")",
     collocatedPipe = os.popen(command + " 2>&1")
     print "ok"
 
@@ -475,8 +482,8 @@ def collocatedTestWithOptions(name, additionalOptions):
     collocatedStatus = closePipe(collocatedPipe)
 
     if collocatedStatus:
-	killServers()
-	sys.exit(1)
+        killServers()
+        sys.exit(1)
 
 def collocatedTest(name):
 
@@ -490,7 +497,7 @@ def clientTestWithOptions(name, additionalOptions):
     print createMsg("client"),
     command = createCmd(client) + clientOptions + " " + additionalOptions
     if debug:
-	print "(" + command + ")",
+        print "(" + command + ")",
     clientPipe = os.popen(command + " 2>&1")
     print "ok"
 
@@ -499,18 +506,13 @@ def clientTestWithOptions(name, additionalOptions):
     clientStatus = closePipe(clientPipe)
 
     if clientStatus:
-	killServers()
-	sys.exit(1)
+        killServers()
+        sys.exit(1)
 
 def clientTest(name):
 
     clientTestWithOptions(name, "")
 
 def cleanDbDir(path):
-
-    files = os.listdir(path)
-
-    for filename in files:
-        if filename != "CVS" and filename != ".dummy":
-            fullpath = os.path.join(path, filename);
-            os.remove(fullpath)
+    for filename in [ os.path.join(path, f) for f in os.listdir(path) if f != ".gitignore"]:
+	os.remove(filename)
