@@ -1,6 +1,6 @@
 // **********************************************************************
 //
-// Copyright (c) 2003-2006 ZeroC, Inc. All rights reserved.
+// Copyright (c) 2003-2007 ZeroC, Inc. All rights reserved.
 //
 // This copy of Ice is licensed to you under the terms described in the
 // ICE_LICENSE file included in this distribution.
@@ -14,27 +14,27 @@ public sealed class CallbackI : CallbackDisp_
 {
     public override void initiateCallback(CallbackReceiverPrx proxy, Ice.Current current)
     {
-        Console.WriteLine("initiating callback");
-	try
-	{
-	    proxy.callback(current.ctx);
-	}
-	catch(System.Exception ex)
-	{
-	    Console.Error.WriteLine(ex);
-	}
+        Console.WriteLine("initiating callback to: " + current.adapter.getCommunicator().proxyToString(proxy));
+        try
+        {
+            proxy.callback(current.ctx);
+        }
+        catch(System.Exception ex)
+        {
+            Console.Error.WriteLine(ex);
+        }
     }
 
     public override void shutdown(Ice.Current current)
     {
         Console.WriteLine("Shutting down...");
-	try
-	{
-	    current.adapter.getCommunicator().shutdown();
-	}
-	catch(System.Exception ex)
-	{
-	    Console.Error.WriteLine(ex);
-	}
+        try
+        {
+            current.adapter.getCommunicator().shutdown();
+        }
+        catch(System.Exception ex)
+        {
+            Console.Error.WriteLine(ex);
+        }
     }
 }
