@@ -1,6 +1,6 @@
 // **********************************************************************
 //
-// Copyright (c) 2003-2006 ZeroC, Inc. All rights reserved.
+// Copyright (c) 2003-2007 ZeroC, Inc. All rights reserved.
 //
 // This copy of Ice is licensed to you under the terms described in the
 // ICE_LICENSE file included in this distribution.
@@ -15,46 +15,38 @@ public class Client : Ice.Application
     private static void menu()
     {
         Console.Write(
-	    "usage:\n" +
-	    "t: send greeting as twoway\n" +
-	    "o: send greeting as oneway\n" +
-	    "O: send greeting as batch oneway\n" +
-	    "d: send greeting as datagram\n" +
-	    "D: send greeting as batch datagram\n" +
-	    "f: flush all batch requests\n" +
-	    "T: set a timeout");
-	if(_haveSSL)
-	{
+            "usage:\n" +
+            "t: send greeting as twoway\n" +
+            "o: send greeting as oneway\n" +
+            "O: send greeting as batch oneway\n" +
+            "d: send greeting as datagram\n" +
+            "D: send greeting as batch datagram\n" +
+            "f: flush all batch requests\n" +
+            "T: set a timeout\n" +
+            "P: set a server delay");
+        if(_haveSSL)
+        {
             Console.Write("\nS: switch secure mode on/off");
-	}
+        }
         Console.WriteLine(
-	    "\ns: shutdown server\n" +
-	    "x: exit\n" +
-	    "?: help\n");
+            "\ns: shutdown server\n" +
+            "x: exit\n" +
+            "?: help\n");
     }
-    
+
     public override int run(string[] args)
     {
-	try
-	{
-	    communicator().getPluginManager().getPlugin("IceSSL");
-	    _haveSSL = true;
-	}
-	catch(Ice.NotRegisteredException)
-	{
-	}
-
-        Ice.Properties properties = communicator().getProperties();
-        string proxyProperty = "Hello.Proxy";
-        string proxy = properties.getProperty(proxyProperty);
-        if(proxy.Length == 0)
+        try
+        {
+            communicator().getPluginManager().getPlugin("IceSSL");
+            _haveSSL = true;
+        }
+        catch(Ice.NotRegisteredException)
         {
-            Console.Error.WriteLine("property `" + proxyProperty + "' not set");
-            return 1;
         }
 
         HelloPrx twoway = HelloPrxHelper.checkedCast(
-	    communicator().stringToProxy(proxy).ice_twoway().ice_timeout(-1).ice_secure(false));
+            communicator().propertyToProxy("Hello.Proxy").ice_twoway().ice_timeout(-1).ice_secure(false));
         if(twoway == null)
         {
             Console.Error.WriteLine("invalid proxy");
@@ -65,8 +57,9 @@ public class Client : Ice.Application
         HelloPrx datagram = HelloPrxHelper.uncheckedCast(twoway.ice_datagram());
         HelloPrx batchDatagram = HelloPrxHelper.uncheckedCast(twoway.ice_batchDatagram());
 
-	bool secure = false;
+        bool secure = false;
         int timeout = -1;
+        int delay = 0;
 
         menu();
 
@@ -84,37 +77,37 @@ public class Client : Ice.Application
                 }
                 if(line.Equals("t"))
                 {
-                    twoway.sayHello();
+                    twoway.sayHello(delay);
                 }
                 else if(line.Equals("o"))
                 {
-                    oneway.sayHello();
+                    oneway.sayHello(delay);
                 }
                 else if(line.Equals("O"))
                 {
-                    batchOneway.sayHello();
+                    batchOneway.sayHello(delay);
                 }
                 else if(line.Equals("d"))
                 {
-		    if(secure)
-		    {
-			Console.WriteLine("secure datagrams are not supported");
-		    }
-		    else
-		    {
-			datagram.sayHello();
-		    }
+                    if(secure)
+                    {
+                        Console.WriteLine("secure datagrams are not supported");
+                    }
+                    else
+                    {
+                        datagram.sayHello(delay);
+                    }
                 }
                 else if(line.Equals("D"))
                 {
-		    if(secure)
-		    {
-			Console.WriteLine("secure datagrams are not supported");
-		    }
-		    else
-		    {
-			batchDatagram.sayHello();
-		    }
+                    if(secure)
+                    {
+                        Console.WriteLine("secure datagrams are not supported");
+                    }
+                    else
+                    {
+                        batchDatagram.sayHello(delay);
+                    }
                 }
                 else if(line.Equals("f"))
                 {
@@ -144,25 +137,45 @@ public class Client : Ice.Application
                         Console.WriteLine("timeout is now set to 2000ms");
                     }
                 }
-		else if(_haveSSL && line.Equals("S"))
-		{
-		    secure = !secure;
+                else if(line.Equals("P"))
+                {
+                    if(delay == 0)
+                    {
+                        delay = 2500;
+                    }
+                    else
+                    {
+                        delay = 0;
+                    }
+                    
+                    if(delay == 0)
+                    {
+                        Console.WriteLine("server delay is now deactivated");
+                    }
+                    else
+                    {
+                        Console.WriteLine("server delay is now set to 2500ms");
+                    }
+                }
+                else if(_haveSSL && line.Equals("S"))
+                {
+                    secure = !secure;
 
-		    twoway = HelloPrxHelper.uncheckedCast(twoway.ice_secure(secure));
-		    oneway = HelloPrxHelper.uncheckedCast(oneway.ice_secure(secure));
-		    batchOneway = HelloPrxHelper.uncheckedCast(batchOneway.ice_secure(secure));
-		    datagram = HelloPrxHelper.uncheckedCast(datagram.ice_secure(secure));
-		    batchDatagram = HelloPrxHelper.uncheckedCast(batchDatagram.ice_secure(secure));
+                    twoway = HelloPrxHelper.uncheckedCast(twoway.ice_secure(secure));
+                    oneway = HelloPrxHelper.uncheckedCast(oneway.ice_secure(secure));
+                    batchOneway = HelloPrxHelper.uncheckedCast(batchOneway.ice_secure(secure));
+                    datagram = HelloPrxHelper.uncheckedCast(datagram.ice_secure(secure));
+                    batchDatagram = HelloPrxHelper.uncheckedCast(batchDatagram.ice_secure(secure));
 
-		    if(secure)
-		    {
-			Console.WriteLine("secure mode is now on");
-		    }
-		    else
-		    {
-			Console.WriteLine("secure mode is now off");
-		    }
-		}
+                    if(secure)
+                    {
+                        Console.WriteLine("secure mode is now on");
+                    }
+                    else
+                    {
+                        Console.WriteLine("secure mode is now off");
+                    }
+                }
                 else if(line.Equals("s"))
                 {
                     twoway.shutdown();
@@ -183,7 +196,7 @@ public class Client : Ice.Application
             }
             catch(System.Exception ex)
             {
-		Console.Error.WriteLine(ex);
+                Console.Error.WriteLine(ex);
             }
         }
         while (!line.Equals("x"));
@@ -195,10 +208,10 @@ public class Client : Ice.Application
     {
         Client app = new Client();
         int status = app.main(args, "config.client");
-	if(status != 0)
-	{
-	    System.Environment.Exit(status);
-	}
+        if(status != 0)
+        {
+            System.Environment.Exit(status);
+        }
     }
 
     private static bool _haveSSL = false;
