@@ -1,6 +1,6 @@
 // **********************************************************************
 //
-// Copyright (c) 2003-2006 ZeroC, Inc. All rights reserved.
+// Copyright (c) 2003-2007 ZeroC, Inc. All rights reserved.
 //
 // This copy of Ice is licensed to you under the terms described in the
 // ICE_LICENSE file included in this distribution.
@@ -26,27 +26,18 @@ public class Client : Ice.Application
                            + "t: Send sequence as twoway\n"
                            + "o: Send sequence as oneway\n" 
                            + "r: Receive sequence\n"
-			   + "e: Echo (send and receive) sequence\n"
+                           + "e: Echo (send and receive) sequence\n"
                            + "\n"
                            + "other commands\n"
                            + "s: shutdown server\n"
-			   + "x: exit\n"
-			   + "?: help\n");
+                           + "x: exit\n"
+                           + "?: help\n");
     }
     
     public override int
     run(string[] args)
     {
-        Ice.Properties properties = communicator().getProperties();
-        string refProperty = "Throughput.Throughput";
-        string r = properties.getProperty(refProperty);
-        if(r.Length == 0)
-        {
-            Console.Error.WriteLine("property `" + r + "' not set");
-            return 1;
-        }
-        
-        Ice.ObjectPrx b = communicator().stringToProxy(r);
+        Ice.ObjectPrx b = communicator().propertyToProxy("Throughput.Throughput");
         ThroughputPrx throughput = ThroughputPrxHelper.checkedCast(b);
         if(throughput == null)
         {
@@ -58,31 +49,68 @@ public class Client : Ice.Application
         byte[] byteSeq = new byte[ByteSeqSize.value];
 
         string[] stringSeq = new string[StringSeqSize.value];
-	for(int i = 0; i < StringSeqSize.value; ++i)
-	{
-	    stringSeq[i] = "hello";
-	}
+        for(int i = 0; i < StringSeqSize.value; ++i)
+        {
+            stringSeq[i] = "hello";
+        }
 
         StringDouble[] structSeq = new StringDouble[StringDoubleSeqSize.value];
         for(int i = 0; i < StringDoubleSeqSize.value; ++i)
         {
-	    structSeq[i] = new StringDouble();
+            structSeq[i] = new StringDouble();
             structSeq[i].s = "hello";
             structSeq[i].d = 3.14;
         }
 
-	Fixed[] fixedSeq = new Fixed[FixedSeqSize.value];
-	for(int i = 0; i < FixedSeqSize.value; ++i)
-	{
-	    fixedSeq[i].i = 0;
-	    fixedSeq[i].j = 0;
-	    fixedSeq[i].d = 0;
-	}
+        Fixed[] fixedSeq = new Fixed[FixedSeqSize.value];
+        for(int i = 0; i < FixedSeqSize.value; ++i)
+        {
+            fixedSeq[i].i = 0;
+            fixedSeq[i].j = 0;
+            fixedSeq[i].d = 0;
+        }
+
+        //
+        // A method needs to be invoked thousands of times before the
+        // JIT compiler will convert it to native code. To ensure an
+        // accurate throughput measurement, we need to "warm up" the
+        // JIT compiler.
+        //
+        {
+            byte[] emptyBytes = new byte[1];
+            string[] emptyStrings = new string[1];
+            StringDouble[] emptyStructs = new StringDouble[1];
+            emptyStructs[0] = new StringDouble();
+            Fixed[] emptyFixed = new Fixed[1];
+
+            throughput.startWarmup();
+
+            Console.Error.Write("warming up the client/server...");
+            Console.Error.Flush();
+            for(int i = 0; i < 10000; i++)
+            {
+                throughput.sendByteSeq(emptyBytes);
+                throughput.sendStringSeq(emptyStrings);
+                throughput.sendStructSeq(emptyStructs);
+                throughput.sendFixedSeq(emptyFixed);
+
+                throughput.recvByteSeq();
+                throughput.recvStringSeq();
+                throughput.recvStructSeq();
+                throughput.recvFixedSeq();
+
+                throughput.echoByteSeq(emptyBytes);
+                throughput.echoStringSeq(emptyStrings);
+                throughput.echoStructSeq(emptyStructs);
+                throughput.echoFixedSeq(emptyFixed);
+            }
+            throughput.endWarmup();
+
+            Console.Error.WriteLine("ok");
+        }
         
         menu();
         
-        throughput.ice_ping(); // Initial ping to setup the connection.
-
         //
         // By default use byte sequence.
         //
@@ -97,10 +125,10 @@ public class Client : Ice.Application
                 Console.Write("==> ");
                 Console.Out.Flush();
                 line = Console.In.ReadLine();
-		if(line == null)
-		{
-		    break;
-		}
+                if(line == null)
+                {
+                    break;
+                }
 
                 long tmsec = System.DateTime.Now.Ticks / 10000;
                 const int repetitions = 100;
@@ -354,31 +382,31 @@ public class Client : Ice.Application
                             break;
                         }
                     }
-		    double mbit = repetitions * seqSize * wireSize * 8.0 / dmsec / 1000.0;
-		    if(c == 'e')
-		    {
-			mbit *= 2;
-		    }
-		    Console.WriteLine("throughput: " + mbit.ToString("#.##") + "Mbps");
-		}
-		else if(line.Equals("s"))
-		{
-		    throughput.shutdown();
-		}
-		else if(line.Equals("x"))
-		{
-		    // Nothing to do
-		}
-		else if(line.Equals("?"))
-		{
-		    menu();
-		}
-		else
-		{
-		    Console.WriteLine("unknown command `" + line + "'");
-		    menu();
-		}
-	    }
+                    double mbit = repetitions * seqSize * wireSize * 8.0 / dmsec / 1000.0;
+                    if(c == 'e')
+                    {
+                        mbit *= 2;
+                    }
+                    Console.WriteLine("throughput: " + mbit.ToString("#.##") + "Mbps");
+                }
+                else if(line.Equals("s"))
+                {
+                    throughput.shutdown();
+                }
+                else if(line.Equals("x"))
+                {
+                    // Nothing to do
+                }
+                else if(line.Equals("?"))
+                {
+                    menu();
+                }
+                else
+                {
+                    Console.WriteLine("unknown command `" + line + "'");
+                    menu();
+                }
+            }
             catch(System.Exception ex)
             {
                 Console.Error.WriteLine(ex);
