@@ -1,6 +1,6 @@
 // **********************************************************************
 //
-// Copyright (c) 2003-2006 ZeroC, Inc. All rights reserved.
+// Copyright (c) 2003-2007 ZeroC, Inc. All rights reserved.
 //
 // This copy of Ice is licensed to you under the terms described in the
 // ICE_LICENSE file included in this distribution.
@@ -22,7 +22,7 @@ public sealed class ThroughputI : ThroughputDisp_
         _structSeq = new StringDouble[StringDoubleSeqSize.value];
         for(int i = 0; i < StringDoubleSeqSize.value; ++i)
         {
-	    _structSeq[i] = new StringDouble();
+            _structSeq[i] = new StringDouble();
             _structSeq[i].s = "hello";
             _structSeq[i].d = 3.14;
         }
@@ -35,13 +35,37 @@ public sealed class ThroughputI : ThroughputDisp_
         }
     }
 
+    public override bool needsWarmup(Ice.Current current)
+    {
+        _warmup = false;
+        return _needsWarmup;
+    }
+
+    public override void startWarmup(Ice.Current current)
+    {
+        _warmup = true;
+    }
+
+    public override void endWarmup(Ice.Current current)
+    {
+        _warmup = false;
+        _needsWarmup = false;
+    }
+
     public override void sendByteSeq(byte[] seq, Ice.Current current)
     {
     }
 
     public override byte[] recvByteSeq(Ice.Current current)
     {
-        return _byteSeq;
+        if(_warmup)
+        {
+            return _emptyByteSeq;
+        }
+        else
+        {
+            return _byteSeq;
+        }
     }
 
     public override byte[] echoByteSeq(byte[] seq, Ice.Current current)
@@ -55,7 +79,14 @@ public sealed class ThroughputI : ThroughputDisp_
 
     public override string[] recvStringSeq(Ice.Current current)
     {
-        return _stringSeq;
+        if(_warmup)
+        {
+            return _emptyStringSeq;
+        }
+        else
+        {
+            return _stringSeq;
+        }
     }
 
     public override string[] echoStringSeq(string[] seq, Ice.Current current)
@@ -69,7 +100,14 @@ public sealed class ThroughputI : ThroughputDisp_
 
     public override StringDouble[] recvStructSeq(Ice.Current current)
     {
-        return _structSeq;
+        if(_warmup)
+        {
+            return _emptyStructSeq;
+        }
+        else
+        {
+            return _structSeq;
+        }
     }
 
     public override StringDouble[] echoStructSeq(StringDouble[] seq, Ice.Current current)
@@ -83,7 +121,14 @@ public sealed class ThroughputI : ThroughputDisp_
 
     public override Fixed[] recvFixedSeq(Ice.Current current)
     {
-        return _fixedSeq;
+        if(_warmup)
+        {
+            return _emptyFixedSeq;
+        }
+        else
+        {
+            return _fixedSeq;
+        }
     }
 
     public override Fixed[] echoFixedSeq(Fixed[] seq, Ice.Current current)
@@ -100,4 +145,12 @@ public sealed class ThroughputI : ThroughputDisp_
     private string[] _stringSeq;
     private StringDouble[] _structSeq;
     private Fixed[] _fixedSeq;
+
+    private byte[] _emptyByteSeq = new byte[0];
+    private string[] _emptyStringSeq = new string[0];
+    private StringDouble[] _emptyStructSeq = new StringDouble[0];
+    private Fixed[] _emptyFixedSeq = new Fixed[0];
+
+    private bool _needsWarmup = true;
+    private bool _warmup = false;
 }
