@@ -1,6 +1,6 @@
 // **********************************************************************
 //
-// Copyright (c) 2003-2006 ZeroC, Inc. All rights reserved.
+// Copyright (c) 2003-2007 ZeroC, Inc. All rights reserved.
 //
 // This copy of Ice is licensed to you under the terms described in the
 // ICE_LICENSE file included in this distribution.
@@ -15,16 +15,7 @@ public class Client : Ice.Application
 {
     public override int run(string[] args)
     {
-        Ice.Properties properties = communicator().getProperties();
-        string refProperty = "Value.Initial";
-        string @ref = properties.getProperty(refProperty);
-        if(@ref.Length == 0)
-        {
-            Console.Error.WriteLine("property `" + refProperty + "' not set");
-            return 1;
-        }
-        
-        Ice.ObjectPrx @base = communicator().stringToProxy(@ref);
+        Ice.ObjectPrx @base = communicator().propertyToProxy("Value.Initial");
         InitialPrx initial = InitialPrxHelper.checkedCast(@base);
         if(initial == null)
         {
@@ -37,7 +28,7 @@ public class Client : Ice.Application
         Console.Out.WriteLine("operations, and print its contents. No factory is required");
         Console.Out.WriteLine("for this.");
         Console.Out.WriteLine("[press enter]");
-	Console.In.ReadLine();
+        Console.In.ReadLine();
         
         Simple simple = initial.getSimple();
         Console.Out.WriteLine("==> " + simple.message);
@@ -54,8 +45,8 @@ public class Client : Ice.Application
         try
         {
             initial.getPrinter(out printer, out printerProxy);
-	    Console.Error.WriteLine("Did not get the expected NoObjectFactoryException!");
-	    Environment.Exit(1);
+            Console.Error.WriteLine("Did not get the expected NoObjectFactoryException!");
+            Environment.Exit(1);
         }
         catch(Ice.NoObjectFactoryException ex)
         {
@@ -101,7 +92,7 @@ public class Client : Ice.Application
         Console.In.ReadLine();
         
         Printer derivedAsBase = initial.getDerivedPrinter();
-        Console.Out.WriteLine("The type ID of the received object is \"" + derivedAsBase.ice_id() + "\"");
+        Console.Out.WriteLine("==> The type ID of the received object is \"" + derivedAsBase.ice_id() + "\"");
         Debug.Assert(derivedAsBase.ice_id().Equals("::Demo::Printer"));
         
         Console.Out.WriteLine();
@@ -117,7 +108,7 @@ public class Client : Ice.Application
         DerivedPrinter derived = (DerivedPrinter)derivedAsBase;
         
         Console.Out.WriteLine("==> class cast to derived object succeded");
-        Console.Out.WriteLine("The type ID of the received object is \"" + derived.ice_id() + "\"");
+        Console.Out.WriteLine("==> The type ID of the received object is \"" + derived.ice_id() + "\"");
         
         Console.Out.WriteLine();
         Console.Out.WriteLine("Let's print the message contained in the derived object, and");
@@ -154,7 +145,7 @@ public class Client : Ice.Application
         Console.Out.WriteLine();
         Console.Out.WriteLine("That's it for this demo. Have fun with Ice!");
         
-	initial.shutdown();
+        initial.shutdown();
 
         return 0;
     }
