@@ -1,6 +1,6 @@
 // **********************************************************************
 //
-// Copyright (c) 2003-2006 ZeroC, Inc. All rights reserved.
+// Copyright (c) 2003-2007 ZeroC, Inc. All rights reserved.
 //
 // This copy of Ice is licensed to you under the terms described in the
 // ICE_LICENSE file included in this distribution.
@@ -15,45 +15,35 @@ public class Client : Ice.Application
     private static void menu()
     {
         Console.Write(
-	    "usage:\n" +
-	    "t: send greeting as twoway\n" +
-	    "o: send greeting as oneway\n" +
-	    "O: send greeting as batch oneway\n" +
-	    "d: send greeting as datagram\n" +
-	    "D: send greeting as batch datagram\n" +
-	    "f: flush all batch requests\n" +
-	    "T: set a timeout");
-	if(_haveSSL)
-	{
-	    Console.Write("\nS: switch secure mode on/off");
-	    }
-	Console.WriteLine(
-	    "\nx: exit\n" +
-	    "?: help\n");
+            "usage:\n" +
+            "t: send greeting as twoway\n" +
+            "o: send greeting as oneway\n" +
+            "O: send greeting as batch oneway\n" +
+            "d: send greeting as datagram\n" +
+            "D: send greeting as batch datagram\n" +
+            "f: flush all batch requests\n");
+        if(_haveSSL)
+        {
+            Console.Write("\nS: switch secure mode on/off");
+        }
+        Console.WriteLine(
+            "\nx: exit\n" +
+            "?: help\n");
     }
     
     public override int run(string[] args)
     {
-	try
-	{
-	    communicator().getPluginManager().getPlugin("IceSSL");
-	    _haveSSL = true;
-	}
-	catch(Ice.NotRegisteredException)
-	{
-	}
-
-        Ice.Properties properties = communicator().getProperties();
-        string proxyProperty = "Hello.Proxy";
-        string proxy = properties.getProperty(proxyProperty);
-        if(proxy.Length == 0)
+        try
         {
-            Console.Error.WriteLine("property `" + proxyProperty + "' not set");
-            return 1;
+            communicator().getPluginManager().getPlugin("IceSSL");
+            _haveSSL = true;
         }
-        
+        catch(Ice.NotRegisteredException)
+        {
+        }
+
         HelloPrx twoway = HelloPrxHelper.checkedCast(
-	    communicator().stringToProxy(proxy).ice_twoway().ice_timeout(-1).ice_secure(false));
+            communicator().propertyToProxy("Hello.Proxy").ice_twoway().ice_timeout(-1).ice_secure(false));
         if(twoway == null)
         {
             Console.Error.WriteLine("invalid proxy");
@@ -64,8 +54,7 @@ public class Client : Ice.Application
         HelloPrx datagram = HelloPrxHelper.uncheckedCast(twoway.ice_datagram());
         HelloPrx batchDatagram = HelloPrxHelper.uncheckedCast(twoway.ice_batchDatagram());
         
-	bool secure = false;
-        int timeout = -1;
+        bool secure = false;
         
         menu();
         
@@ -95,73 +84,49 @@ public class Client : Ice.Application
                 }
                 else if(line.Equals("d"))
                 {
-		    if(secure)
-		    {
-			Console.WriteLine("secure datagrams are not supported");
-		    }
-		    else
-		    {
-			datagram.sayHello();
-		    }
+                    if(secure)
+                    {
+                        Console.WriteLine("secure datagrams are not supported");
+                    }
+                    else
+                    {
+                        datagram.sayHello();
+                    }
                 }
                 else if(line.Equals("D"))
                 {
-		    if(secure)
-		    {
-			Console.WriteLine("secure datagrams are not supported");
-		    }
-		    else
-		    {
-			batchDatagram.sayHello();
-		    }
+                    if(secure)
+                    {
+                        Console.WriteLine("secure datagrams are not supported");
+                    }
+                    else
+                    {
+                        batchDatagram.sayHello();
+                    }
                 }
                 else if(line.Equals("f"))
                 {
                     communicator().flushBatchRequests();
                 }
-                else if(line.Equals("T"))
-                {
-                    if(timeout == -1)
-                    {
-                        timeout = 2000;
-                    }
-                    else
-                    {
-                        timeout = -1;
-                    }
-                    
-                    twoway = HelloPrxHelper.uncheckedCast(twoway.ice_timeout(timeout));
-                    oneway = HelloPrxHelper.uncheckedCast(oneway.ice_timeout(timeout));
-                    batchOneway = HelloPrxHelper.uncheckedCast(batchOneway.ice_timeout(timeout));
-                    
-                    if(timeout == -1)
-                    {
-                        Console.WriteLine("timeout is now switched off");
-                    }
-                    else
-                    {
-                        Console.WriteLine("timeout is now set to 2000ms");
-                    }
-                }
                 else if(_haveSSL && line.Equals("S"))
                 {
-		    secure = !secure;
+                    secure = !secure;
 
-		    twoway = HelloPrxHelper.uncheckedCast(twoway.ice_secure(secure));
-		    oneway = HelloPrxHelper.uncheckedCast(oneway.ice_secure(secure));
-		    batchOneway = HelloPrxHelper.uncheckedCast(batchOneway.ice_secure(secure));
-		    datagram = HelloPrxHelper.uncheckedCast(datagram.ice_secure(secure));
-		    batchDatagram = HelloPrxHelper.uncheckedCast(batchDatagram.ice_secure(secure));
-		    
-		    if(secure)
-		    {
-			Console.WriteLine("secure mode is now on");
-		    }
-		    else
-		    {
-			Console.WriteLine("secure mode is now off");
-		    }
-		}
+                    twoway = HelloPrxHelper.uncheckedCast(twoway.ice_secure(secure));
+                    oneway = HelloPrxHelper.uncheckedCast(oneway.ice_secure(secure));
+                    batchOneway = HelloPrxHelper.uncheckedCast(batchOneway.ice_secure(secure));
+                    datagram = HelloPrxHelper.uncheckedCast(datagram.ice_secure(secure));
+                    batchDatagram = HelloPrxHelper.uncheckedCast(batchDatagram.ice_secure(secure));
+                    
+                    if(secure)
+                    {
+                        Console.WriteLine("secure mode is now on");
+                    }
+                    else
+                    {
+                        Console.WriteLine("secure mode is now off");
+                    }
+                }
                 else if(line.Equals("x"))
                 {
                     // Nothing to do
@@ -178,7 +143,7 @@ public class Client : Ice.Application
             }
             catch(System.Exception ex)
             {
-		Console.Error.WriteLine(ex);
+                Console.Error.WriteLine(ex);
             }
         }
         while (!line.Equals("x"));
