@@ -1,6 +1,6 @@
 // **********************************************************************
 //
-// Copyright (c) 2003-2006 ZeroC, Inc. All rights reserved.
+// Copyright (c) 2003-2007 ZeroC, Inc. All rights reserved.
 //
 // This copy of Ice is licensed to you under the terms described in the
 // ICE_LICENSE file included in this distribution.
@@ -20,7 +20,7 @@ class HelloServiceI : Ice.LocalObjectImpl, IceBox.Service
 
     public void stop()
     {
-        _adapter.deactivate();
+        _adapter.destroy();
     }
 
     private Ice.ObjectAdapter _adapter;
