@@ -1,6 +1,6 @@
 // **********************************************************************
 //
-// Copyright (c) 2003-2006 ZeroC, Inc. All rights reserved.
+// Copyright (c) 2003-2007 ZeroC, Inc. All rights reserved.
 //
 // This copy of Ice is licensed to you under the terms described in the
 // ICE_LICENSE file included in this distribution.
@@ -18,14 +18,8 @@ using System.Runtime.CompilerServices;
 [assembly: AssemblyCompany("ZeroC, Inc.")]
 [assembly: AssemblyConfiguration("")]
 [assembly: AssemblyProduct("Glacier2 for C#")]
-[assembly: AssemblyCopyright("Copyright (c) 2003-2005, ZeroC, Inc.")]
+[assembly: AssemblyCopyright("Copyright (c) 2003-2007, ZeroC, Inc.")]
 [assembly: AssemblyTrademark("Ice")]
-[assembly: AssemblyCulture("")]		
-[assembly: AssemblyVersion("3.1.1")]
+[assembly: AssemblyCulture("")]         
+[assembly: AssemblyVersion("3.2.1")]
 [assembly: AssemblyDelaySign(false)]
-#if __MonoCS__
-[assembly: AssemblyKeyFile("../../config/IcecsKey.snk")] // mcs uses different search algorithm.
-#elif ICE_DOTNET_1X
-[assembly: AssemblyKeyFile("../../../../config/IcecsKey.snk")]
-#endif
-[assembly: AssemblyKeyName("")]
