@@ -1,6 +1,6 @@
 // **********************************************************************
 //
-// Copyright (c) 2003-2006 ZeroC, Inc. All rights reserved.
+// Copyright (c) 2003-2007 ZeroC, Inc. All rights reserved.
 //
 // This copy of Ice is licensed to you under the terms described in the
 // ICE_LICENSE file included in this distribution.
@@ -18,31 +18,27 @@ namespace Ice
     // the identity and the facet name as the hash key.
     //
 
-#if ICE_DOTNET_1X
-    public class ProxyIdentityKey : System.Collections.IHashCodeProvider, System.Collections.IComparer
-#else
     public class ProxyIdentityKey : System.Collections.IEqualityComparer, System.Collections.IComparer
-#endif
     {
-	public int GetHashCode(object obj)
-	{
+        public int GetHashCode(object obj)
+        {
             return ((Ice.ObjectPrx)obj).ice_getIdentity().GetHashCode();
-	}
+        }
 
-	public new bool Equals(object obj1, object obj2)
-	{
-	    try
-	    {
-		return Compare(obj1, obj2) == 0;
-	    }
-	    catch(System.Exception)
-	    {
-	        return false;
-	    }
-	}
+        public new bool Equals(object obj1, object obj2)
+        {
+            try
+            {
+                return Compare(obj1, obj2) == 0;
+            }
+            catch(System.Exception)
+            {
+                return false;
+            }
+        }
 
-	public int Compare(object obj1, object obj2)
-	{
+        public int Compare(object obj1, object obj2)
+        {
             if(obj1 == null)
             {
                 return obj2 == null ? 0 : -1;
@@ -61,43 +57,39 @@ namespace Ice
                 {
                     throw new System.ArgumentException("Argument must be derived from Ice.ObjectPrx", "o2");
                 }
-		Ice.Identity i1 = ((Ice.ObjectPrx)obj1).ice_getIdentity();
-		Ice.Identity i2 = ((Ice.ObjectPrx)obj2).ice_getIdentity();
-		int comp = string.Compare(i1.name, i2.name, false, CultureInfo.InvariantCulture);
-		if(comp != 0)
-		{
-		    return comp;
-		}
-		return string.Compare(i1.category, i2.category, false, CultureInfo.InvariantCulture);
+                Ice.Identity i1 = ((Ice.ObjectPrx)obj1).ice_getIdentity();
+                Ice.Identity i2 = ((Ice.ObjectPrx)obj2).ice_getIdentity();
+                int comp = string.Compare(i1.name, i2.name, false, CultureInfo.InvariantCulture);
+                if(comp != 0)
+                {
+                    return comp;
+                }
+                return string.Compare(i1.category, i2.category, false, CultureInfo.InvariantCulture);
             }
-	}
+        }
     }
 
-#if ICE_DOTNET_1X
-    public class ProxyIdentityFacetKey : System.Collections.IHashCodeProvider, System.Collections.IComparer
-#else
     public class ProxyIdentityFacetKey : System.Collections.IEqualityComparer, System.Collections.IComparer
-#endif
     {
-	public int GetHashCode(object obj)
-	{
-	    Ice.ObjectPrx o = (Ice.ObjectPrx)obj;
-	    Ice.Identity identity = o.ice_getIdentity();
-	    string facet = o.ice_getFacet();
-	    return 5 * identity.GetHashCode() + facet.GetHashCode();
-	}
+        public int GetHashCode(object obj)
+        {
+            Ice.ObjectPrx o = (Ice.ObjectPrx)obj;
+            Ice.Identity identity = o.ice_getIdentity();
+            string facet = o.ice_getFacet();
+            return 5 * identity.GetHashCode() + facet.GetHashCode();
+        }
 
-	public new bool Equals(object obj1, object obj2)
-	{
-	    try
-	    {
-		return Compare(obj1, obj2) == 0;
-	    }
-	    catch(System.Exception)
-	    {
-	        return false;
-	    }
-	}
+        public new bool Equals(object obj1, object obj2)
+        {
+            try
+            {
+                return Compare(obj1, obj2) == 0;
+            }
+            catch(System.Exception)
+            {
+                return false;
+            }
+        }
 
         public int Compare(object obj1, object obj2)
         {
