@@ -1,6 +1,6 @@
 // **********************************************************************
 //
-// Copyright (c) 2003-2006 ZeroC, Inc. All rights reserved.
+// Copyright (c) 2003-2007 ZeroC, Inc. All rights reserved.
 //
 // This copy of Ice is licensed to you under the terms described in the
 // ICE_LICENSE file included in this distribution.
@@ -13,7 +13,7 @@ public class Server : Ice.Application
 {
     private static void usage()
     {
-        Console.Error.WriteLine("Usage: IceBox.Server [options] --Ice.Config=<file>\n");
+        Console.Error.WriteLine("Usage: iceboxnet [options] --Ice.Config=<file>\n");
         Console.Error.WriteLine(
             "Options:\n" +
             "-h, --help           Show this message.\n"
@@ -22,29 +22,29 @@ public class Server : Ice.Application
 
     public override int run(string[] args)
     {
-	for(int i = 1; i < args.Length; ++i)
-	{
-	    if(args[i].Equals("-h") || args[i].Equals("--help"))
-	    {
-		usage();
-		return 0;
-	    }
-	    else if(!args[i].StartsWith("--"))
-	    {
-		Console.Error.WriteLine("Server: unknown option `" + args[i] + "'");
-		usage();
-		return 1;
-	    }
-	}
+        for(int i = 0; i < args.Length; ++i)
+        {
+            if(args[i].Equals("-h") || args[i].Equals("--help"))
+            {
+                usage();
+                return 0;
+            }
+            else if(!args[i].StartsWith("--"))
+            {
+                Console.Error.WriteLine("Server: unknown option `" + args[i] + "'");
+                usage();
+                return 1;
+            }
+        }
 
-	ServiceManagerI serviceManagerImpl = new ServiceManagerI(args);
-	return serviceManagerImpl.run();
+        ServiceManagerI serviceManagerImpl = new ServiceManagerI(args);
+        return serviceManagerImpl.run();
     }
 
     public static void Main(string[] args)
     {
-	Server server = new Server();
-	int status = server.main(args);
+        Server server = new Server();
+        int status = server.main(args);
         if(status != 0)
         {
             System.Environment.Exit(status);
