@@ -1,6 +1,6 @@
 // **********************************************************************
 //
-// Copyright (c) 2003-2006 ZeroC, Inc. All rights reserved.
+// Copyright (c) 2003-2007 ZeroC, Inc. All rights reserved.
 //
 // This copy of Ice is licensed to you under the terms described in the
 // ICE_LICENSE file included in this distribution.
@@ -8,6 +8,7 @@
 // **********************************************************************
 
 using Test;
+using System.Diagnostics;
 
 public sealed class ServantLocatorI : Ice.LocalObjectImpl, Ice.ServantLocator
 {
@@ -37,9 +38,9 @@ class Server : Ice.Application
 {
     public override int run(string[] args)
     {
-	communicator().getProperties().setProperty("BackendAdapter.Endpoints", "tcp -p 12010 -t 10000");
+        communicator().getProperties().setProperty("BackendAdapter.Endpoints", "tcp -p 12010 -t 10000");
         Ice.ObjectAdapter adapter = communicator().createObjectAdapter("BackendAdapter");
-	adapter.addServantLocator(new ServantLocatorI(), "");
+        adapter.addServantLocator(new ServantLocatorI(), "");
         adapter.activate();
         communicator().waitForShutdown();
         return 0;
@@ -47,11 +48,13 @@ class Server : Ice.Application
 
     public static void Main(string[] args)
     {
+        Debug.Listeners.Add(new ConsoleTraceListener());
+
         Server app = new Server();
-	int status = app.main(args);
-	if(status != 0)
-	{
-	    System.Environment.Exit(status);
-	}
+        int status = app.main(args);
+        if(status != 0)
+        {
+            System.Environment.Exit(status);
+        }
     }
 }
