@@ -1,6 +1,6 @@
 // **********************************************************************
 //
-// Copyright (c) 2003-2006 ZeroC, Inc. All rights reserved.
+// Copyright (c) 2003-2007 ZeroC, Inc. All rights reserved.
 //
 // This copy of Ice is licensed to you under the terms described in the
 // ICE_LICENSE file included in this distribution.
@@ -36,34 +36,33 @@ public class AllTests
         test(obj.Equals(@base));
         Console.Out.WriteLine("ok");
 
-	{
-	    Console.Out.Write("creating/destroying/recreating object adapter... ");
-	    Console.Out.Flush();
-	    Ice.ObjectAdapter adapter =
-	        communicator.createObjectAdapterWithEndpoints("TransientTestAdapter", "default -p 9999");
-	    try
-	    {
-	        communicator.createObjectAdapterWithEndpoints("TransientTestAdapter", "default -p 9998");
-		test(false);
-	    }
-	    catch(Ice.AlreadyRegisteredException)
-	    {
-	    }
-	    adapter.deactivate();
-	    adapter.waitForDeactivate();
-	    //
-	    // Use a different port than the first adapter to avoid an "address already in use" error.
-	    //
-	    adapter = communicator.createObjectAdapterWithEndpoints("TransientTestAdapter", "default -p 9998");
-	    adapter.deactivate();
-	    adapter.waitForDeactivate();
-	    Console.Out.WriteLine("ok");
-	}
+        {
+            Console.Out.Write("creating/destroying/recreating object adapter... ");
+            Console.Out.Flush();
+            Ice.ObjectAdapter adapter =
+                communicator.createObjectAdapterWithEndpoints("TransientTestAdapter", "default -p 9999");
+            try
+            {
+                communicator.createObjectAdapterWithEndpoints("TransientTestAdapter", "default -p 9998");
+                test(false);
+            }
+            catch(Ice.AlreadyRegisteredException)
+            {
+            }
+            adapter.destroy();
+
+            //
+            // Use a different port than the first adapter to avoid an "address already in use" error.
+            //
+            adapter = communicator.createObjectAdapterWithEndpoints("TransientTestAdapter", "default -p 9998");
+            adapter.destroy();
+            Console.Out.WriteLine("ok");
+        }
         
-	Console.Out.Write("creating/activating/deactivating object adapter in one operation... ");
-	Console.Out.Flush();
-	obj.transient();
-	Console.Out.WriteLine("ok");
+        Console.Out.Write("creating/activating/deactivating object adapter in one operation... ");
+        Console.Out.Flush();
+        obj.transient();
+        Console.Out.WriteLine("ok");
 
         Console.Out.Write("deactivating object adapter in the server... ");
         Console.Out.Flush();
@@ -72,15 +71,15 @@ public class AllTests
 
         Console.Out.Write("testing whether server is gone... ");
         Console.Out.Flush();
-	try
-	{
-	    obj.ice_ping();
-	    throw new System.ApplicationException();
-	}
-	catch(Ice.LocalException)
-	{
-	    Console.Out.WriteLine("ok");
-	}
+        try
+        {
+            obj.ice_ping();
+            throw new System.ApplicationException();
+        }
+        catch(Ice.LocalException)
+        {
+            Console.Out.WriteLine("ok");
+        }
         
         return obj;
     }
