@@ -1,12 +1,14 @@
 // **********************************************************************
 //
-// Copyright (c) 2003-2006 ZeroC, Inc. All rights reserved.
+// Copyright (c) 2003-2007 ZeroC, Inc. All rights reserved.
 //
 // This copy of Ice is licensed to you under the terms described in the
 // ICE_LICENSE file included in this distribution.
 //
 // **********************************************************************
 
+using System.Diagnostics;
+
 public class Server
 {
     internal class TestServer : Ice.Application
@@ -25,11 +27,13 @@ public class Server
     
     public static void Main(string[] args)
     {
+        Debug.Listeners.Add(new ConsoleTraceListener());
+
         TestServer app = new TestServer();
         int result = app.main(args);
-	if(result != 0)
-	{
-	    System.Environment.Exit(result);
-	}
+        if(result != 0)
+        {
+            System.Environment.Exit(result);
+        }
     }
 }
