@@ -1,6 +1,6 @@
 // **********************************************************************
 //
-// Copyright (c) 2003-2006 ZeroC, Inc. All rights reserved.
+// Copyright (c) 2003-2007 ZeroC, Inc. All rights reserved.
 //
 // This copy of Ice is licensed to you under the terms described in the
 // ICE_LICENSE file included in this distribution.
@@ -18,13 +18,12 @@ public sealed class TestI : TestIntfDisp_
         Ice.ObjectAdapter adapter =
             communicator.createObjectAdapterWithEndpoints("TransientTestAdapter", "default -p 9999");
         adapter.activate();
-        adapter.deactivate();
-        adapter.waitForDeactivate();
+        adapter.destroy();
     }
 
     public override void deactivate(Ice.Current current)
     {
         current.adapter.deactivate();
-	System.Threading.Thread.Sleep(new System.TimeSpan(10 * 1000));
+        System.Threading.Thread.Sleep(new System.TimeSpan(10 * 1000));
     }
 }
