@@ -1,6 +1,6 @@
 // **********************************************************************
 //
-// Copyright (c) 2003-2006 ZeroC, Inc. All rights reserved.
+// Copyright (c) 2003-2007 ZeroC, Inc. All rights reserved.
 //
 // This copy of Ice is licensed to you under the terms described in the
 // ICE_LICENSE file included in this distribution.
@@ -8,6 +8,7 @@
 // **********************************************************************
 
 using System;
+using System.Diagnostics;
 
 public class Client
 {
@@ -20,33 +21,35 @@ public class Client
 
     public static void Main(string[] args)
     {
-	int status = 0;
-	Ice.Communicator communicator = null;
-	
-	try
-	{
-	    communicator = Ice.Util.initialize(ref args);
-	    status = run(args, communicator);
-	}
-	catch(System.Exception ex)
-	{
-	    Console.Error.WriteLine(ex);
-	    status = 1;
-	}
-	
-	if(communicator != null)
-	{
-	    try
-	    {
-		communicator.destroy();
-	    }
-	    catch(Ice.LocalException ex)
-	    {
-		Console.Error.WriteLine(ex);
-		status = 1;
-	    }
-	}
-	
+        int status = 0;
+        Ice.Communicator communicator = null;
+        
+        Debug.Listeners.Add(new ConsoleTraceListener());
+
+        try
+        {
+            communicator = Ice.Util.initialize(ref args);
+            status = run(args, communicator);
+        }
+        catch(System.Exception ex)
+        {
+            Console.Error.WriteLine(ex);
+            status = 1;
+        }
+        
+        if(communicator != null)
+        {
+            try
+            {
+                communicator.destroy();
+            }
+            catch(Ice.LocalException ex)
+            {
+                Console.Error.WriteLine(ex);
+                status = 1;
+            }
+        }
+        
         if(status != 0)
         {
             System.Environment.Exit(status);
