@@ -1,12 +1,14 @@
 // **********************************************************************
 //
-// Copyright (c) 2003-2006 ZeroC, Inc. All rights reserved.
+// Copyright (c) 2003-2007 ZeroC, Inc. All rights reserved.
 //
 // This copy of Ice is licensed to you under the terms described in the
 // ICE_LICENSE file included in this distribution.
 //
 // **********************************************************************
 
+using System.Diagnostics;
+
 public sealed class DummyLogger : Ice.LocalObjectImpl, Ice.Logger
 {
     public void print(string message)
@@ -31,7 +33,7 @@ public class Server
     private static int run(string[] args, Ice.Communicator communicator)
     {
         Ice.Properties properties = communicator.getProperties();
-	// We don't need to disable warnings because we have a dummy logger.
+        // We don't need to disable warnings because we have a dummy logger.
         //properties.setProperty("Ice.Warn.Dispatch", "0");
         properties.setProperty("TestAdapter.Endpoints", "default -p 12010 -t 2000:udp");
         Ice.ObjectAdapter adapter = communicator.createObjectAdapter("TestAdapter");
@@ -47,14 +49,16 @@ public class Server
         int status = 0;
         Ice.Communicator communicator = null;
         
+        Debug.Listeners.Add(new ConsoleTraceListener());
+
         try
         {
-	    //
-	    // For this test, we need a dummy logger, otherwise the
-	    // assertion test will print an error message.
-	    //
-	    Ice.InitializationData initData = new Ice.InitializationData();
-	    initData.logger = new DummyLogger();
+            //
+            // For this test, we need a dummy logger, otherwise the
+            // assertion test will print an error message.
+            //
+            Ice.InitializationData initData = new Ice.InitializationData();
+            initData.logger = new DummyLogger();
             communicator = Ice.Util.initialize(ref args, initData);
             status = run(args, communicator);
         }
@@ -77,9 +81,9 @@ public class Server
             }
         }
         
-	if(status != 0)
-	{
-	    System.Environment.Exit(status);
-	}
+        if(status != 0)
+        {
+            System.Environment.Exit(status);
+        }
     }
 }
