@@ -1,12 +1,14 @@
 // **********************************************************************
 //
-// Copyright (c) 2003-2006 ZeroC, Inc. All rights reserved.
+// Copyright (c) 2003-2007 ZeroC, Inc. All rights reserved.
 //
 // This copy of Ice is licensed to you under the terms described in the
 // ICE_LICENSE file included in this distribution.
 //
 // **********************************************************************
 
+using System.Diagnostics;
+
 public class Collocated
 {
     private static int run(string[] args, Ice.Communicator communicator)
@@ -16,9 +18,9 @@ public class Collocated
         Ice.Object d = new DI();
         adapter.add(d, communicator.stringToIdentity("d"));
         adapter.addFacet(d, communicator.stringToIdentity("d"), "facetABCD");
-	Ice.Object f = new FI();
+        Ice.Object f = new FI();
         adapter.addFacet(f, communicator.stringToIdentity("d"), "facetEF");
-	Ice.Object h = new HI(communicator);
+        Ice.Object h = new HI(communicator);
         adapter.addFacet(h, communicator.stringToIdentity("d"), "facetGH");
  
         AllTests.allTests(communicator);
@@ -31,6 +33,8 @@ public class Collocated
         int status = 0;
         Ice.Communicator communicator = null;
         
+        Debug.Listeners.Add(new ConsoleTraceListener());
+
         try
         {
             communicator = Ice.Util.initialize(ref args);
@@ -50,14 +54,14 @@ public class Collocated
             }
             catch(Ice.LocalException ex)
             {
-		System.Console.WriteLine(ex);
+                System.Console.WriteLine(ex);
                 status = 1;
             }
         }
         
-	if(status != 0)
-	{
-	    System.Environment.Exit(status);
-	}
+        if(status != 0)
+        {
+            System.Environment.Exit(status);
+        }
     }
 }
