@@ -1,12 +1,14 @@
 // **********************************************************************
 //
-// Copyright (c) 2003-2006 ZeroC, Inc. All rights reserved.
+// Copyright (c) 2003-2007 ZeroC, Inc. All rights reserved.
 //
 // This copy of Ice is licensed to you under the terms described in the
 // ICE_LICENSE file included in this distribution.
 //
 // **********************************************************************
 
+using System.Diagnostics;
+
 public class Server
 {
     private static int run(string[] args, Ice.Communicator communicator)
@@ -32,6 +34,8 @@ public class Server
         int status = 0;
         Ice.Communicator communicator = null;
         
+        Debug.Listeners.Add(new ConsoleTraceListener());
+
         try
         {
             communicator = Ice.Util.initialize(ref args);
@@ -39,7 +43,7 @@ public class Server
         }
         catch(System.Exception ex)
         {
-	    System.Console.WriteLine(ex);
+            System.Console.WriteLine(ex);
             status = 1;
         }
         
@@ -51,14 +55,14 @@ public class Server
             }
             catch(Ice.LocalException ex)
             {
-		System.Console.WriteLine(ex);
+                System.Console.WriteLine(ex);
                 status = 1;
             }
         }
         
-	if(status != 0)
-	{
-	    System.Environment.Exit(status);
-	}
+        if(status != 0)
+        {
+            System.Environment.Exit(status);
+        }
     }
 }
