@@ -1,12 +1,14 @@
 // **********************************************************************
 //
-// Copyright (c) 2003-2006 ZeroC, Inc. All rights reserved.
+// Copyright (c) 2003-2007 ZeroC, Inc. All rights reserved.
 //
 // This copy of Ice is licensed to you under the terms described in the
 // ICE_LICENSE file included in this distribution.
 //
 // **********************************************************************
 
+using System.Diagnostics;
+
 public class Server
 {
     private static int run(string[] args, Ice.Communicator communicator,
@@ -18,7 +20,7 @@ public class Server
         // communicator and object adapter).
         //
         Ice.Properties properties = communicator.getProperties();
-	properties.setProperty("Ice.ThreadPool.Server.Size", "2");
+        properties.setProperty("Ice.ThreadPool.Server.Size", "2");
         properties.setProperty("ServerManagerAdapter.Endpoints", "default -p 12010 -t 30000:udp");
         
         Ice.ObjectAdapter adapter = communicator.createObjectAdapter("ServerManagerAdapter");
@@ -33,7 +35,7 @@ public class Server
         adapter.add(@object, communicator.stringToIdentity("ServerManager"));
         registry.addObject(adapter.createProxy(communicator.stringToIdentity("ServerManager")));
         Ice.LocatorRegistryPrx registryPrx = Ice.LocatorRegistryPrxHelper.uncheckedCast(
-						adapter.add(registry, communicator.stringToIdentity("registry")));
+                                                adapter.add(registry, communicator.stringToIdentity("registry")));
         
         ServerLocator locator = new ServerLocator(registry, registryPrx);
         adapter.add(locator, communicator.stringToIdentity("locator"));
@@ -49,6 +51,8 @@ public class Server
         int status = 0;
         Ice.Communicator communicator = null;
         
+        Debug.Listeners.Add(new ConsoleTraceListener());
+
         try
         {
             Ice.InitializationData initData = new Ice.InitializationData();
