@@ -1,14 +1,14 @@
 // **********************************************************************
 //
-// Copyright (c) 2003-2006 ZeroC, Inc. All rights reserved.
+// Copyright (c) 2003-2007 ZeroC, Inc. All rights reserved.
 //
 // This copy of Ice is licensed to you under the terms described in the
 // ICE_LICENSE file included in this distribution.
 //
 // **********************************************************************
 
-using System.Diagnostics;
 using Test;
+using System.Diagnostics;
 
 public class Client
 {
@@ -28,6 +28,26 @@ public class Client
             {
                 return new DI();
             }
+            else if(type.Equals("::Test::E"))
+            {
+                return new EI();
+            }
+            else if(type.Equals("::Test::F"))
+            {
+                return new FI();
+            }
+            else if(type.Equals("::Test::I"))
+            {
+                return new II();
+            }
+            else if(type.Equals("::Test::J"))
+            {
+                return new JI();
+            }
+            else if(type.Equals("::Test::H"))
+            {
+                return new HI();
+            }
             Debug.Assert(false); // Should never be reached
             return null;
         }
@@ -41,10 +61,15 @@ public class Client
 
     private static int run(string[] args, Ice.Communicator communicator)
     {
-	Ice.ObjectFactory factory = new MyObjectFactory();
-	communicator.addObjectFactory(factory, "::Test::B");
-	communicator.addObjectFactory(factory, "::Test::C");
-	communicator.addObjectFactory(factory, "::Test::D");
+        Ice.ObjectFactory factory = new MyObjectFactory();
+        communicator.addObjectFactory(factory, "::Test::B");
+        communicator.addObjectFactory(factory, "::Test::C");
+        communicator.addObjectFactory(factory, "::Test::D");
+        communicator.addObjectFactory(factory, "::Test::E");
+        communicator.addObjectFactory(factory, "::Test::F");
+        communicator.addObjectFactory(factory, "::Test::I");
+        communicator.addObjectFactory(factory, "::Test::J");
+        communicator.addObjectFactory(factory, "::Test::H");
 
         InitialPrx initial = AllTests.allTests(communicator, false);
         initial.shutdown();
@@ -55,7 +80,9 @@ public class Client
     {
         int status = 0;
         Ice.Communicator communicator = null;
-        
+
+        Debug.Listeners.Add(new ConsoleTraceListener());
+
         try
         {
             communicator = Ice.Util.initialize(ref args);
