@@ -1,20 +1,56 @@
 // **********************************************************************
 //
-// Copyright (c) 2003-2006 ZeroC, Inc. All rights reserved.
+// Copyright (c) 2003-2007 ZeroC, Inc. All rights reserved.
 //
 // This copy of Ice is licensed to you under the terms described in the
 // ICE_LICENSE file included in this distribution.
 //
 // **********************************************************************
 
+using System.Diagnostics;
+
 public class Server
 {
+    private class MyObjectFactory : Ice.LocalObjectImpl, Ice.ObjectFactory
+    {
+        public Ice.Object create(string type)
+        {
+            if(type.Equals("::Test::I"))
+            {
+                return new II();
+            }
+            else if(type.Equals("::Test::J"))
+            {
+                return new JI();
+            }
+            else if(type.Equals("::Test::H"))
+            {
+                return new HI();
+            }
+            Debug.Assert(false); // Should never be reached
+            return null;
+        }
+
+        public void
+        destroy()
+        {
+            // Nothing to do
+        }
+    }
+
     private static int run(string[] args, Ice.Communicator communicator)
     {
+        Ice.ObjectFactory factory = new MyObjectFactory();
+        communicator.addObjectFactory(factory, "::Test::I");
+        communicator.addObjectFactory(factory, "::Test::J");
+        communicator.addObjectFactory(factory, "::Test::H");
+
         communicator.getProperties().setProperty("TestAdapter.Endpoints", "default -p 12010 -t 2000");
         Ice.ObjectAdapter adapter = communicator.createObjectAdapter("TestAdapter");
         Ice.Object @object = new InitialI(adapter);
         adapter.add(@object, communicator.stringToIdentity("initial"));
+        @object = new UnexpectedObjectExceptionTestI();
+        adapter.add(@object, communicator.stringToIdentity("uoet"));
         adapter.activate();
         communicator.waitForShutdown();
         return 0;
@@ -25,6 +61,8 @@ public class Server
         int status = 0;
         Ice.Communicator communicator = null;
         
+        Debug.Listeners.Add(new ConsoleTraceListener());
+
         try
         {
             communicator = Ice.Util.initialize(ref args);
