@@ -1,6 +1,6 @@
 // **********************************************************************
 //
-// Copyright (c) 2003-2006 ZeroC, Inc. All rights reserved.
+// Copyright (c) 2003-2007 ZeroC, Inc. All rights reserved.
 //
 // This copy of Ice is licensed to you under the terms described in the
 // ICE_LICENSE file included in this distribution.
@@ -8,6 +8,7 @@
 // **********************************************************************
 
 using Test;
+using System.Diagnostics;
 
 public class Client
 {
@@ -23,6 +24,8 @@ public class Client
         int status = 0;
         Ice.Communicator communicator = null;
         
+        Debug.Listeners.Add(new ConsoleTraceListener());
+
         try
         {
             communicator = Ice.Util.initialize(ref args);
@@ -30,7 +33,7 @@ public class Client
         }
         catch(System.Exception ex)
         {
-	    System.Console.Error.WriteLine(ex);
+            System.Console.Error.WriteLine(ex);
             status = 1;
         }
         
@@ -42,7 +45,7 @@ public class Client
             }
             catch(Ice.LocalException ex)
             {
-		System.Console.Error.WriteLine(ex);
+                System.Console.Error.WriteLine(ex);
                 status = 1;
             }
         }
